<?php

namespace Drupal\moderation_dashboard\Plugin\views\field;

use Drupal\Core\Url;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;

/**
 * A Views field which provides a link to the latest version of an Entity.
 *
 * @ViewsField("link_to_latest_version")
 */
class LinkToLatestVersion extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $module_handler = \Drupal::moduleHandler();
    if ($module_handler->moduleExists('workbench_moderation')) {
      /** @var \Drupal\workbench_moderation\ModerationInformation $information */
      $information = \Drupal::service('workbench_moderation.moderation_information');
      $is_moderated = 'isModeratableEntity';
      $has_forward = 'hasForwardRevision';
    }
    else if ($module_handler->moduleExists('content_moderation')) {
      /** @var \Drupal\content_moderation\ModerationInformation $information */
      $information = \Drupal::service('content_moderation.moderation_information');
      $is_moderated = 'isModeratedEntity';
      $has_forward = 'hasPendingRevision';
    }
    else {
      return [];
    }
    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    $entity = $this->getEntity($values);
    $entity_type_id = $entity->getEntityTypeId();
    if (call_user_func([$information, $is_moderated], $entity) && call_user_func([$information, $has_forward], $entity)) {
      $entity = $information->getLatestRevision($entity_type_id, $entity->id());
      $build = [
        '#title' => $entity->label(),
        '#type' => 'link',
        '#url' => Url::fromRoute("entity.{$entity_type_id}.latest_version", [
          $entity_type_id => $entity->id(),
        ]),
      ];
    }
    else {
      $build = [
        '#title' => $entity->label(),
        '#type' => 'link',
        '#url' => $entity->toLink()->getUrl(),
      ];
    }

    return $build;
  }

}
