<?php

namespace Drupal\Tests\replicate_ui\Functional;

use Drupal\Core\Cache\Cache;
use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use Drupal\Tests\AssertHelperTrait;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests the UI functionality.
 *
 * @group replicate
 */
class ReplicateUITest extends BrowserTestBase {

  use AssertHelperTrait;

  /**
   * {@inheritdoc}
   */
  public static $modules = ['replicate', 'replicate_ui', 'node', 'block'];

  /**
   * @var \Drupal\user\UserInterface
   */
  protected $user;

  /**
   * @var \Drupal\node\NodeInterface
   */
  protected $node;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->user = $this->drupalCreateUser([
      'bypass node access',
      'administer nodes',
      'replicate entities',
      'administer users',
    ]);
    $node_type = NodeType::create([
      'type' => 'page',
    ]);
    $node_type->save();
    $this->node = Node::create([
      'title' => 'test title',
      'type' => 'page',
    ]);
    $this->node->save();

    $this->placeBlock('local_tasks_block');
    $this->placeBlock('system_messages_block');
    $this->config('replicate_ui.settings')
      ->set('entity_types', [
        'node',
        'user',
      ])
      ->save();
    \Drupal::service('router.builder')->rebuild();
    Cache::invalidateTags(['entity_types']);
  }

  public function testFunctionality() {
    $this->drupalGet($this->node->toUrl());
    $this->assertSession()->pageTextNotContains('Replicate');

    $this->drupalLogin($this->user);
    $this->drupalGet($this->node->toUrl());
    $this->assertSession()->pageTextContains('Replicate');
    $this->assertSession()->statusCodeEquals(200);

    $this->getSession()->getPage()->clickLink('Replicate');
    $this->assertSession()->statusCodeEquals(200);

    // Test the new label form element on the confirmation page.
    $this->assertSession()->pageTextContains('New label');
    $this->assertSession()->pageTextContains('This text will be used as the label of the new entity being created.');
    $new_element_label = $this->assertSession()->elementExists('css', 'input[name="new_label"]');
    $this->assertequals($this->node->label() . ' (Copy)', $new_element_label->getValue());
    $this->getSession()->getPage()->fillField('new_label', 'Overriden replicate label');
    $this->getSession()->getPage()->pressButton('Replicate');
    $this->getSession()->getPage()->getContent();
    $this->assertSession()->responseContains('<em class="placeholder">node</em> (<em class="placeholder">1</em>) has been replicated to id <em class="placeholder">2</em>!');
    $this->assertSession()->titleEquals('Overriden replicate label | Drupal');
    // Check that we don't show the new label element on entities without a
    // label key.
    $this->drupalGet("/user/{$this->user->id()}/replicate");
    $this->getSession()->getPage()->clickLink('Replicate');
    $this->assertSession()->pageTextContains('Are you sure you want to replicate user entity id');
    $this->assertSession()->elementNotExists('css', 'input[name="new_label"]');
    $this->assertSession()->pageTextNotContains('New label');
    $this->assertSession()->pageTextNotContains('This text will be used as the label of the new entity being created.');
  }

}
